Learn R Programming

gdimap (version 0.0-3)

dsi203_bmax4000: DSI b-Table File

Description

3D grid b-table file used in diffusion data acquisition for data set data.nii.gz (alias "DSI 203-point 3mm"), as provided by the Advanced Biomedical MRI Lab, National Taiwan University Hospital, and referenced in the package DSI_Studio developed by Fang-Cheng Yeh.

Arguments

References

Yeh, F.-C., Wedeen, V. J., and Tseng, W.-Y. I. Generalized q- Sampling Imaging. IEEE Transactions on Medical Imaging 29, 9 (2010), 1626--1635.

NITRC repository, http://www.nitrc.org.