Learn R Programming

gdimap (version 0.0-3)

gdimap-package: Generalized Diffusion Magnetic Resonance Imaging

Description

The package implements algorithms to estimate and visualize the orientation of neuronal pathways in model-free methods (q-space imaging methods). For fibre orientation estimation based on mixtures of von Mises-Fischer (vMF) distributions see gqi.odfvmflines, and gqi.odfvmf. For fibre orientation estimation based on local peak detection procedures see gqi.odfpeaklines, and gqi.odfpeaks. Visualization of RGB-maps and glyph-maps is implemented through rgbvolmap and gqi.odfvxgrid, respectively. Various types of simulations of diffusion and ODF profiles, illustrating the application of vMF mixtures for fibre orientation estimation are implemented in simulglyph.vmf, simul.simplefield, simul.fandtasia. Data sets used in the examples are documented.

Arguments

Details

For a complete list of functions type library(help=gdimap).