Usage
gqi.odfpeaklines(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL, rg=c(1,1),
swap=FALSE, lambda=NULL, depth=3, btoption=2, threshold=0.4, kdir=2,
zfactor=5, showglyph=FALSE, snapshot=FALSE, showimage="linesgfa",
bview="coronal", savedir=tempdir(), pngfig="odfpeak", bg="white",
texture=NULL, ...)
Arguments
gdi
method of ODF reconstruction to use c("gqi", "gqi2") (default: "gqi").
run
logical variable enabling loading previously processed data (default: TRUE).
fbase
Directory where the required input data files are located.
roi
Region of Interest (ROI) to use as mask; default mask (roi=NULL) uses an all brain mask for the supplied data set.
rg
range of slices to process (default option rg=c(1,1)); rg=NULL processes all slices.
swap
toggle radiological/neurological orientation (default: FALSE).
lambda
diffusion sampling length in gdi="gqi" and gdi="gqi2".
By default the following default values are used when lambda=NULL is specified: 1.24 in "gqi", 3 in "gqi2".
depth
sampling density on the hemisphere used in simulation (default N=321; depth=3).
btoption
b-table selection between btable.txt (btoption=1), and the 3D-DSI grid b-table
extracted from the diffusion data set (data.bvec and data.bval). By default, the 3D-DSI grid b-table is used (btopti
threshold
thresholding generalized fractional anisotropy (GFA) value at each voxel (default: 0.4).
kdir
maximum number of fibre directions to map (default: 2).
zfactor
parameter controlling z-value in relief overlay maps (default: 5).
showglyph
logical variable controlling visualization of voxel glyphs (default: FALSE).
snapshot
logical variable controlling line-map snapshots (default: FALSE).
showimage
object controlling visualization of line-maps (default: "linesgfa").
Alternative options are:
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata")
(see Details).
bview
MRI slice view selection in {axial, coronal, sagittal} (default: "coronal").
savedir
directory for saving/loading processed results (default: tempdir().
pngfig
base-name of the PNG file when snapshot is TRUE (default "odfpeak").
bg
map background colour (default "white")
texture
name of the PNG file to be used as RGB map overlay in some 'showimage' options (default NULL - no texture).
...
additional material properties for geometry appearance as specified in rgl.material.