gqi.odfvmf(gdi="gqi", run=TRUE, fbase=NULL, rg=NULL, swap=FALSE, lambda=NULL,
depth=3, btoption=2, threshold=0.4, showglyph=FALSE, bview="coronal",
savedir=tempdir())c("gqi", "gqi2") (default: "gqi").TRUE).rg=NULL processes all slices.FALSE).gdi="gqi" and gdi="gqi2".
By default the following default values are used when lambda=NULL is specified: 1.24 in btoption=1), and the 3D-DSI grid b-table extracted from the diffusion data set (btoptionaxial, coronal, sagittal} (default: "coronal").FALSE).tempdir().gqi.odfvmf outputs three data files in NIfTI format named
gqi.odfvmf uses a mixture of 2 and 4 von Mises-Fisher (vMF) distributions that serves as a model for directional ODF profile data, corresponding to multiple fibre orientations.
Statistical orientation estimation in gqi.odfvmf is based on von Mises clustering procedures provided by the R-package Starting with the raw diffusion signal acquired on a grid of q-space, the ODF profile is estimated at each voxel, considering a sampling density of unit vectors on a unit S2 grid. When a threshold is applied to the estimated ODF at each voxel, the non-thresholded unit vectors provide directional statistics information about the estimated ODF profile. The main ODF orientations at each voxel relevant for fibre tracking may be estimated by clustering the non-thresholded unit vectors.
The main diffusion data set used in the examples is a DICOM data set provided by the "Advanced Biomedical MRI Lab, National Taiwan University Hospital", which is included in the "DSI Studio" package, publicly available from the NITRC repository (
The output files niinorm.
Ferreira da Silva, A. R. Facing the Challenge of Estimating Human Brain White Matter Pathways. In Proc. of the 4th International Joint Conference on Computational Intelligence (Oct. 2012), K. Madani, J. Kacprzyk, and J. Filipe, Eds., SciTePress, pp. 709-714.
Hornik, K., and Gruen, B.
Yeh, F.-C., Wedeen, V. J., and Tseng, W.-Y. I. Generalized q-Sampling Imaging. IEEE Transactions on Medical Imaging 29, 9 (2010), 1626-1635.
Garyfallidis E., Towards an Accurate Brain Tractography, 2012, PhD Thesis, University of Cambridge.
Jenkinson, M., Beckmann, C. F., Behrens, T. E., Woolrich, M. W., and Smith, S. M. FSL. NeuroImage 62, 2 (2012), 782-790.
gqi.odfvmflines,
gqi.odfpeaklines,
gqi.odfvxgrid,
rgbvolmap,
gqi.odfpeaks,
s2tessel.zorder,
plotglyph,
simulglyph.vmf,
simul.fandtasia,
simul.simplefield,
data,
data.bval,
data.bvec,
btable## Generate ODF volumes (GQI volume processing)
## for a range of slices using von Mises-Fisher clustering
gqi.odfvmf(depth=2, showglyph=FALSE, threshold=0.5, savedir=tempdir())
## RGB maps for range of slices processed by gqi.odfvmf()
rgbvolmap(fbase=tempdir(), rg=c(1,4), bview="coronal")
##-------------
## Show reconstructed glyphs in ODF processing
## for first and second main fibre direction determination
gqi.odfvmf(gdi="gqi", rg=c(1,1), bview="coronal", depth=3,
showglyph=TRUE, threshold=0.5)
gqi.odfvmf(gdi="gqi2", rg=c(1,1), bview="coronal", depth=3,
showglyph=TRUE, threshold=0.5)Run the code above in your browser using DataLab