Learn R Programming

gdimap (version 0.0-3)

gqi.odfvmflines: Fibre Orientation Mapping Based on von Mises-Fisher Distributions

Description

In order to enable mapping complex white matter fibres in the brain, gqi.odfvmflines implements a new methodology based on directional statistics to estimate fibre profiles from high angular resolution diffusion imaging data. Statistical orientation estimation in gqi.odfvmf is based on von Mises-Fisher clustering procedures provided by the R-package movMF, by Kurt Hornik and Bettina Gruen.

Usage

gqi.odfvmflines(run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE,
 mddratio=1.24, depth=3, btoption=2, threshold=0.4, kdir=4, zfactor=5,
 showglyph=FALSE, snapshot=FALSE, showimage="linesgfa", bview="coronal",
 savedir=tempdir(), pngfig="odfvmf", bg="white", texturefile=NA)

Arguments

run
logical variable enabling loading previously processed data (default: TRUE).
fbase
Directory where the required input data files are located.
roi
Region of Interest (ROI) to use as mask; default mask (roi=NULL) uses an all brain mask for the supplied data set.
rg
range of slices to process (default option rg=c(1,1)); rg=NULL processes all slices.
swap
toggle radiological/neurological orientation (default: FALSE).
mddratio
GQI parameter (default: 1.24).
depth
sampling density on the hemisphere used in simulation (default N=321; depth=3).
btoption
b-table selection between dsi203_bmax4000.txt (btoption=1), and the 3D-DSI grid b-table extracted from the diffusion data set (data.bvec and data.bval). By default, the 3D-DSI grid b-table is used (
threshold
thresholding generalized fractional anisotropy (GFA) value at each voxel (default: 0.4).
kdir
maximum number of fibre directions to map (default: 4).
zfactor
parameter controlling z-value in relief overlay maps (default: 5).
showglyph
logical variable controlling visualization of voxel glyphs (default: FALSE).
snapshot
logical variable controlling line-maps snapshots (default: FALSE).
showimage
object controlling visualization of line-maps (default: "linesgfa"). Alternative options are: c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata") (see Details).
bview
MRI slice view selection in {axial, coronal, sagittal} (default: "coronal").
savedir
directory for saving/loading processed results (default: tempdir().
pngfig
base-name of the PNG file when snapshot is TRUE (default "odfvmf").
bg
map background colour (default "white")
texturefile
name of the PNG file to be used as RGB map overlay in some 'showimage' options (default NA - no texture).

Value

  • gqi.odfvmflines produces line-maps of ODF profiles for diffusion data slices. The line-maps may be overlayed with generalized fractional anisotropy (GFA) relief maps, diffusion data maps or ROI maps. The file V1list.RData containing the first main orientation directions for all processed voxels is output for further posterior orientation processing.

concept

  • Diffusion Magnetic Resonance
  • GQI Reconstruction
  • von Mises Distributions
  • Fibre Orientation Mapping

Details

Generalized q-Sampling Imaging (GQI) is used for orientation distribution function (ODF) reconstruction. The function gqi.odfvmflines implements a mixture-model approach to clustering orientation distribution functions (ODFs) based on the von Mises-Fisher distributions. The method focus on clustering data on the unit sphere, where complexity arises from representing ODF profiles as directional data.

Starting with the raw diffusion signal acquired on a grid of q-space, the ODF profile is estimated at each voxel, considering a sampling density of unit vectors on a unit S2 grid. When a threshold is applied to the estimated ODF at each voxel, the non-thresholded unit vectors provide directional statistics information about the estimated ODF profile. The main ODF orientations at each voxel relevant for fibre tracking may be estimated by clustering the non-thresholded unit vectors.

The main diffusion data set used in the examples is a DICOM data set provided by the "Advanced Biomedical MRI Lab, National Taiwan University Hospital", which is included in the "DSI Studio" package, publicly available from the NITRC repository (http://www.nitrc.org). Two b-tables defining the acquisition setup are specified. One is a b-table for a S2-like grid denoted by dsi203_bmax4000.txt. The other is the b-table for the 3D-DSI sampling scheme used in the DICOM data acquisition. This b-table has 203 points uniformly distributed on a 3D grid limited to the volume of the unit sphere. In both tables, the b-values range from 0 to 4000.

Slice map display and overlay selection is controlled by specifying one the arguments c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata") for showimages. Meanings are as follows: "none" - no visualization; "gfa" - GFA map only; "lines" - line map only; "linesgfa" - GFA overlayed on line map; "linesrgbmap" - lines overlayed on RGB map (if available); "linesdata" - data_brain.nii.gz is overlayed on line map.

References

Ferreira da Silva, A. R. Facing the Challenge of Estimating Human Brain White Matter Pathways. In Proc. of the 4th International Joint Conference on Computational Intelligence (Oct. 2012), K. Madani, J. Kacprzyk, and J. Filipe, Eds., SciTePress, pp. 709-714.

Hornik, K., and Gruen, B. movMF: Mixtures of von Mises-Fisher Distributions, 2012. R package version 0.1-0.

Yeh, F.-C., Wedeen, V. J., and Tseng, W.-Y. I. Generalized q-Sampling Imaging. IEEE Transactions on Medical Imaging 29, 9 (2010), 1626-1635.

Hankin, R. K. S. Special functions in R: introducing the gsl package. R News 6 (October 2006).

Adler, D., and Murdoch, D. rgl: 3D visualization device system (OpenGL), 2012. R package version 0.92.880.

Auguie, B. gridExtra: functions in Grid graphics, 2012. R package version 0.9.1.

Barber, C. B., Habel, K., Grasman, R., Gramacy, R. B., Stahel, A., and Sterratt, D. C. geometry: Mesh generation and surface tesselation, 2012. R package version 0.3-2.

R Core Team. R: A Language and Environment for Statistical Computing. R Foundation for Statistical Computing, Vienna, Austria, 2012. ISBN 3-900051-07-0.

Whitcher, B., Schmid, V. J., and Thornton, A. Working with the DICOM and NIfTI data standards in R. Journal of Statistical Software 44, 6 (2011), 1-28.

Jenkinson, M., Beckmann, C. F., Behrens, T. E., Woolrich, M. W., and Smith, S. M. FSL. NeuroImage 62, 2 (2012), 782-790.

Zeileis, A., Hornik, K., and Murrell, P. Escaping RGBland: Selecting colors for statistical graphics. Computational Statistics & Data Analysis 53 (2009), 3259-3270.

See Also

gqi.odfvmf, gqi.odfpeaks, gqi.odfvmflines, gqi.odfvxgrid, plotglyph, rgbvolmap, s2tessel.zorder, simulglyph.vmf, simul.fandtasia, simul.simplefield, data, data_brain, data.bval, data.bvec, dsi203_bmax4000

Examples

Run this code
##-------------
  ## von Mises-Fisher fibre orientation mapping
  ## for a range of slices
  gqi.odfvmflines(run=TRUE, rg=c(1,1), depth=2,
    showimage="linesdata", threshold=0.5)
  ## display line-maps only
  gqi.odfvmflines(run=FALSE, depth=2, showimage="lines")
  ## using GFA overlay
  gqi.odfvmflines(run=FALSE, depth=2, showimage="linesgfa")
  ##-------------
  ## Show reconstructed glyphs in ODF processing 
  ## for principal direction determination
  gqi.odfvmflines(run=TRUE, depth=3,
    showimage="linesdata", showglyph=TRUE, threshold=0.5)
  ##-------------
  ## using a ROI overlay
  gqi.odfvmflines(run=TRUE, depth=3, roi="slfcst")
  ##-------------
  ## coronal view with texture for a single slice
  rgbvolmap(texture=TRUE, transparent=TRUE)
  gqi.odfvmflines(threshold=0.5, showimage="linesrgbmap",
    texturefile=paste(tempdir(),"/rgbmap.png", sep=""))

Run the code above in your browser using DataLab