Learn R Programming

gdimap (version 0.0-3)

rgbvolmap: Generalized Fractional Anisotropy (GFA) Maps (RGB Maps)

Description

Using GFA data and the main direction of ODF profiles produced by gqi.odfpeaks or gqi.odfvmf, rgbvolmap displays RGB maps.

Usage

rgbvolmap(fbase=NULL, rg=c(1,1),  bview="coronal",
 texture=FALSE, transparent=FALSE,  saveplot=FALSE,
 pngfile=paste(tempdir(),"/rgbmap.png",sep="") )

Arguments

fbase
Directory where the required input data files are located.
rg
range of slices to process (default option rg=c(1,1)); rg=NULL processes all slices.
bview
MRI slice view selection in {axial, coronal, sagittal} (default: "coronal").
texture
logical variable for texture generation texture=FALSE); texture=TRUE is used for generating PNG file to be used as texture in overlay maps.
transparent
background colour {white, black} (default black background: FALSE).
saveplot
logical variable controlling plot saving (default: FALSE).
pngfile
PNG file name and location to use when saveplot is TRUE (default paste(tempdir(),"/rgbvolmap.png",sep="")).

concept

RGB maps

Details

The standard convention for colour assignment when combining GFA values with directional information is adopted (see Pajevic, et.al.; Jellison et.al.). Colour hue indicates direction as follows: red, left-right; green, antero-posterior; blue, superior-inferior. Brightness is proportional to GFA. The output files data_V1_gqi.nii.gz and data_gfa_gqi.nii.gz are compatible with the "FSL/fslview" tool for RGB map and line map visualization.

References

Ferreira da Silva, A. R. Facing the Challenge of Estimating Human Brain White Matter Pathways. In Proc. of the 4th International Joint Conference on Computational Intelligence (Oct. 2012), K. Madani, J. Kacprzyk, and J. Filipe, Eds., SciTePress, pp. 709-714.

Auguie, B. gridExtra: functions in Grid graphics, 2012. R package version 0.9.1.

Pajevic, S., and Pierpaoli, C. Color Schemes to Represent the Orien- tation of Anisotropic Tissues From Diffusion Tensor Data: Application to White Matter Fiber Tract Mapping in the Human Brain. Magnetic Resonance in Medicine 42 (1999), 526-540.

Jellison, B. J., Field, A. S., Medow, J., Lazar, M., Salamat, M. S., and Alexander, A. L. Diffusion tensor imaging of cerebral white matter: A pictorial review of physics, fiber tract anatomy, and tumor imaging patterns. AJNR Am. J. Neuroradiology 25 (2004), 356-369.

See Also

gqi.odfpeaks, gqi.odfpeaklines, gqi.odfvmf, gqi.odfvmflines, gqi.odfvxgrid, plotglyph, s2tessel.zorder

Examples

Run this code
##-------------
    ## Generate ODF volumes (GQI volume processing) for
    ## range of slices using deterministic find peaks algorithm
    gqi.odfpeaks(rg=c(1,1), showglyph=FALSE)
    ## Show RGB maps for range of slices processed by gqi.odfpeaks()
    rgbvolmap(fbase=tempdir(), rg=c(1,1))
    ## White background
    rgbvolmap(fbase=tempdir(), rg=c(1,1), transparent=TRUE)
    ##-------------
    ## Process whole volume: generates NIfTI files
    ##   data_gfa_gqi.nii.gz and data_V1_gqi.nii.gz
    gqi.odfpeaks(rg=NULL)
    ## Visualization of RBG maps generated by vMF function "gqi.odfvmf"
    ## (cf. FSL/fslview tool) 
    rgbvolmap(fbase=tempdir(), rg=NULL, bview="coronal")

Run the code above in your browser using DataLab