sph.odfpeaklines produces line-maps of ODF profiles for diffusion data slices using
a regularized spheric harmonics method for ODF reconstruction.sph.odfpeaklines(run=TRUE, fbase=NULL, roi=NULL, rg=c(1,1), btoption=1,
swap=FALSE, threshold=0.4, kdir=2, zfactor=5, showglyph=FALSE,
snapshot=FALSE, showimage="linesgfa", bview="coronal", savedir=tempdir(),
pngfig="odfpeak", bg="white", order=4, texture=NULL, ...)TRUE).roi=NULL) uses an all brain mask
for the supplied data set.rg=c(1,1)); rg=NULL processes all slices.btoption=1)
or user defined files. With btoption=2, diffusion data files FALSE).FALSE).FALSE)."linesgfa").
Alternative options are:
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata")
(see Details).axial, coronal, sagittal} (default: "coronal").tempdir()).snapshot is TRUE (default "odfpeak")."white")NULL - no texture).rgl.material.sph.odfpeaklines produces line-maps of ODF profiles for diffusion data slices.
The line-maps may be overlayed with generalized fractional anisotropy (GFA) relief maps, diffusion data maps or ROI maps.
The file sph.odfpeaklines implements the standard method of fibre orientation detection.
Local maxima of the reconstructed ODF are located simply by selecting a large number of sampled points on the sphere and searching within a fixed radius neighbourhood.
For a single main fibre orientation the method performs well.
However, for crossing fibres and other complex fibre configurations the peaks of the ODF profiles identified by the methods do not necessarily match the orientations of the distinct fibre populations.
A more robust method is implemented in sph.odfvmflines.Starting with the raw high angular resolution diffusion signal acquired on a S2-shell of q-space, the ODF profile is reconstructed at each voxel, considering a sampling density of unit vectors on a unit S2 shell.
Q-ball imaging (QBI) is used for orientation distribution function (ODF) reconstruction.
For comparison with GQI, the b-table
Slice map display and overlay selection is controlled by specifying one the arguments
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata") for showimages.
Meanings are as follows:
"none" - no visualization;
"gfa" - GFA map only;
"lines" - line map only;
"linesgfa" - GFA overlayed on line map;
"linesrgbmap" - lines overlayed on RGB map (if available);
"linesdata" -
Ferreira da Silva, A. R. Facing the Challenge of Estimating Human Brain White Matter Pathways. In Proc. of the 4th International Joint Conference on Computational Intelligence (Oct. 2012), K. Madani, J. Kacprzyk, and J. Filipe, Eds., SciTePress, pp. 709-714.
Tuch D. S., Q-Ball Imaging, Magnetic Resonance in Medicine 52 (2004), 1358-1372.
Tabelow K., Polzehl J.:
sph.odfpeaks,
sph.odfvmf,
sph.odfvmflines,
gqi.odfvxgrid,
s2tessel.zorder,
plotglyph,
rgbvolmap,
simulglyph.vmf,
simul.fandtasia,
simul.simplefield,
data,
data.bval,
data.bvec,
btable##-------------
## Line map using ODF peak detection
sph.odfpeaklines(run=TRUE, showimage="lines")
## display line-map overlayed on GFA map
sph.odfpeaklines(run=FALSE, showimage="linesgfa")
##-------------
## Show examples of reconstructed glyphs in ODF processing
sph.odfpeaklines(showimage="lines", showglyph=TRUE)
##------------
## using a ROI overlay
sph.odfpeaklines(roi="slfcst", showimage="linesgfa")
## using data overlay
sph.odfpeaklines(showimage="linesdata")Run the code above in your browser using DataLab