sph.odfvmflines implements a new methodology based on directional statistics to estimate fibre profiles from high angular resolution diffusion imaging data.
Statistical orientation estimation in sph.odfvmf is based on von Mises-Fisher clustering procedures provided by the R-package sph.odfvmflines(run=TRUE, fbase=NULL, roi=NULL, rg=c(1,1), swap=FALSE,
btoption=1, threshold=0.4, kdir=4, zfactor=5, showglyph=FALSE,
snapshot=FALSE, showimage="linesgfa", bview="coronal", savedir=tempdir(),
pngfig="odfvmf", bg="white", texturefile=NA, order=4)TRUE).roi=NULL) uses an all brain mask for the supplied data set.rg=c(1,1)); rg=NULL processes all slices.FALSE).btoption=1)
or user defined files. With btoption=2, diffusion data files FALSE).FALSE)."linesgfa").
Alternative options are:
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata")
(see Details).axial, coronal, sagittal} (default: "coronal").tempdir().snapshot is TRUE (default "odfvmf")."white")NA - no texture).sph.odfvmflines produces line-maps of ODF profiles for diffusion data slices.
The line-maps may be overlayed with generalized fractional anisotropy (GFA) relief maps, diffusion data maps or ROI maps.
The file sph.odfvmflines implements a mixture-model approach to clustering orientation distribution functions (ODFs) based on the von Mises-Fisher distributions.
The method focus on clustering data on the unit sphere, where complexity arises from representing ODF profiles as directional data.Starting with the raw high angular resolution diffusion signal acquired on a S2-shell of q-space, the ODF profile is reconstructed at each voxel, considering a sampling density of unit vectors on a unit S2 shell.
Q-ball imaging (QBI) is used for orientation distribution function (ODF) reconstruction.
For comparison with GQI, the b-table
Slice map display and overlay selection is controlled by specifying one the arguments
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata")
for showimages.
Meanings are as follows: "none" - no visualization; "gfa" - GFA map only; "lines" - line map only; "linesgfa" - GFA overlayed on line map; "linesrgbmap" - lines overlayed on RGB map (if available); "linesdata" -
Hornik, K., and Gruen, B.
Tuch D. S., Q-Ball Imaging, Magnetic Resonance in Medicine 52 (2004), 1358-1372.
Tabelow K., Polzehl J.:
sph.odfvmf,
sph.odfpeaks,
sph.odfvmflines,
gqi.odfvxgrid,
plotglyph,
rgbvolmap,
s2tessel.zorder,
simulglyph.vmf,
simul.fandtasia,
simul.simplefield,
data,
data.bval,
data.bvec,
btable##-------------
## von Mises-Fisher fibre orientation mapping
## for a range of slices
sph.odfvmflines(run=TRUE, rg=c(1,1), showimage="linesdata",
threshold=0.5)
## display line-maps only
sph.odfvmflines(run=FALSE, showimage="lines")
## using GFA overlay
sph.odfvmflines(run=FALSE, showimage="linesgfa")
##-------------
## Show reconstructed glyphs in ODF processing
## for principal direction determination
sph.odfvmflines(run=TRUE, showimage="linesdata",
showglyph=TRUE, threshold=0.5)
##-------------
## using a ROI overlay
sph.odfvmflines(run=TRUE, roi="slfcst")Run the code above in your browser using DataLab