Learn R Programming

gdimap (version 0.1-3)

synthfiberss2z: Voxel Diffusion Profiles for Multiple Fibre Simulation

Description

synthfiberss2z simulates apparent diffusion coefficient (ADC) profiles in multi-direction, diffusion-weighted MR data, for testing ODF reconstruction and fibre orientation estimation.

Usage

synthfiberss2z(g0, angles=c(20,100), b=3000, S0=1, sigma=NULL,
 logplot=TRUE, pos=c(0,0,0), showglyph=FALSE, new=TRUE, wi=NULL)

Arguments

g0
matrix of 3D points on the S2 shell used in simulation.
angles
angles in degrees of fibres to be used in simulation (default: two fibres with angles c(20,100)).
b
strength of the magnetic diffusion gradient (default b-value=3000).
S0
signal intensity without the diffusion weighting (default: 1).
sigma
Rician noise level used in simulation (default NULL).
logplot
logical variable for selecting log-scale (default TRUE).
pos
3D positional coordinate (default c(0,0,0)).
showglyph
logical variable controlling visualization of voxel glyph (default: TRUE).
new
starts a new figure if TRUE (default new=TRUE).
wi
weight given to fiber's volume fraction. Example for two fibers with different weights wi=c(0.7,0.3) (default NULL gives equal weigth to all fibers.)

Value

  • synthfiberss2z plots the diffusion profile and returns the synthesized diffusion signal.

concept

  • Simulation
  • Diffusion signal simulation
  • Glyph mapping

Details

The simulation models the profile of the ADC over the sphere. Prolate diffusion tensor (DT) white matter profiles are estimated with eigenvalues {1700, 200, 200}(x 10^(-6) mm2/s) (see D.C. Alexander, 2002). Diffusion profiles for crossing fibres are simulated from prolate DTs in equal proportions, where each fibre is represented by a prolate DT. Noisy profiles may be simulated by adding Rician noise to the simulated diffusion profile, with a user defined standard deviation level specified as $\sigma$ (SNR=1/$\sigma$). Typically, noise values of SNR~30 are used in simulated dMRI.

References

Barber, C. B., Habel, K., Grasman, R., Gramacy, R. B., Stahel, A., and Sterratt, D. C. geometry: Mesh generation and surface tessellation, 2012. R package version 0.3-2.

Adler, D., and Murdoch, D. rgl: 3D visualization device system (OpenGL), 2012. R package version 0.92.880.

Alexander, D. C., Barker, G. J., and Arridge, S. R. Detection and Modeling of Non-Gaussian Apparent Diffusion Coefficient Profiles in Human Brain Data. Magnetic Resonance in Medicine 48 (2002), 331-340.

See Also

simulglyph.vmf, plotglyph gqi.odfvmflines, rgbvolmap, gqi.odfpeaks, gqi.odfpeaklines, gqi.odfvxgrid, simulglyph.vmf, simul.fandtasia, simul.simplefield

Examples

Run this code
## S2 grid
    s2 <- s2tessel.zorder(depth=3)
    g0 <- s2$pc
    ## synthetize diffusion signal (two crossing fibres)
    open3d()
    angles=c(20,100); b=3000
    S <- synthfiberss2z(g0=g0, angles=angles, b=b)
    ## synthetize signal with different volume fractions
    S <- synthfiberss2z(g0=g0, angles=angles, b=b, wi=c(0.7,0.3))
    ## synthesize diffusion signal (three crossing fibres)
    angles <- c(0,60,120); b <- 3000
    S <- synthfiberss2z(g0=g0, angles=angles, b=b)

Run the code above in your browser using DataLab