gqi.odfpeaklines produces line-maps of ODF profiles for diffusion data slices.gqi.odfpeaklines(run=TRUE, fbase=NULL, roi=NULL, rg=c(1,1), swap=FALSE,
mddratio=1.24, depth=3, btoption=2, threshold=0.4, kdir=2, zfactor=5,
showglyph=FALSE, snapshot=FALSE, showimage="linesgfa", bview="coronal",
savedir=tempdir(), pngfig="odfpeak", bg="white", texturefile=NA)TRUE).roi=NULL) uses an all brain mask for the supplied data set.rg=c(1,1)); rg=NULL processes all slices.FALSE).btoption=1), and the 3D-DSI grid b-table
extracted from the diffusion data set (FALSE).FALSE)."linesgfa").
Alternative options are:
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata")
(see Details).axial, coronal, sagittal} (default: "coronal").tempdir().snapshot is TRUE (default "odfpeak")."white")NA - no texture).gqi.odfpeaklines produces line-maps of ODF profiles for diffusion data slices.
The line-maps may be overlayed with generalized fractional anisotropy (GFA) relief maps, diffusion data maps or ROI maps.
The file gqi.odfpeaklines implements the standard method of fibre orientation detection.
Local maxima of the reconstructed ODF are located simply by selecting a large number of sampled points on the sphere and searching within a fixed radius neighbourhood.
For a single main fibre orientation the method performs well.
However, for crossing fibres and other complex fibre configurations the peaks of the ODF profiles identified by the methods do not necessarily match the orientations of the distinct fibre populations.
A more robust method is implemented in gqi.odfvmflines.Starting with the raw high angular resolution diffusion signal acquired on a grid of q-space, the ODF profile is reconstructed at each voxel, considering a sampling density of unit vectors on a unit S2 grid.
Generalized q-Sampling Imaging (GQI) is used for orientation distribution function (ODF) reconstruction.
Two b-tables defining the acquisition setup are specified.
One is a b-table for a S2-like grid denoted by
Slice map display and overlay selection is controlled by specifying one the arguments
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata") for showimages.
Meanings are as follows:
"none" - no visualization;
"gfa" - GFA map only;
"lines" - line map only;
"linesgfa" - GFA overlayed on line map;
"linesrgbmap" - lines overlayed on RGB map (if available);
"linesdata" -
Yeh, F.-C., Wedeen, V. J., and Tseng, W.-Y. I. Generalized q-Sampling Imaging. IEEE Transactions on Medical Imaging 29, 9 (2010), 1626-1635.
Whitcher, B., Schmid, V. J., and Thornton, A. Working with the DICOM and NIfTI data standards in R. Journal of Statistical Software 44, 6 (2011), 1-28.
Hankin, R. K. S. Special functions in R: introducing the
Adler, D., and Murdoch, D.
Auguie, B.
Barber, C. B., Habel, K., Grasman, R., Gramacy, R. B., Stahel, A., and Sterratt, D. C.
R Core Team.
Jenkinson, M., Beckmann, C. F., Behrens, T. E., Woolrich, M. W., and Smith, S. M. FSL. NeuroImage 62, 2 (2012), 782-790.
Zeileis, A., Hornik, K., and Murrell, P. Escaping RGBland: Selecting colors for statistical graphics. Computational Statistics & Data Analysis 53 (2009), 3259-3270.
gqi.odfpeaks,
gqi.odfvmf,
gqi.odfvmflines,
gqi.odfvxgrid,
s2tessel.zorder,
plotglyph,
rgbvolmap,
simulglyph.vmf,
simul.fandtasia,
simul.simplefield,
data,
data_brain,
data.bval,
data.bvec,
dsi203_bmax4000##-------------
## Line map using ODF peak detection
gqi.odfpeaklines(run=TRUE, showimage="lines")
## display line-map overlayed on GFA map
gqi.odfpeaklines(run=FALSE, showimage="linesgfa")
##-------------
## generate slice texture first from default data file
rgbvolmap(texture=TRUE, transparent=TRUE)
## Line map with RGB map overlay
gqi.odfpeaklines(run=TRUE, showimage="linesrgbmap",
texturefile=paste(tempdir(),"/rgbmap.png", sep=""))
##-------------
## Show examples of reconstructed glyphs in ODF processing
gqi.odfpeaklines(showimage="lines", showglyph=TRUE)
##------------
## using a ROI overlay
gqi.odfpeaklines(roi="slfcst", showimage="linesgfa")
## using data overlay
gqi.odfpeaklines(showimage="linesdata")Run the code above in your browser using DataLab