gqi.odfvmf(run=TRUE, fbase=NULL, rg=NULL, swap=FALSE, mddratio=1.24,
depth=3, btoption=2, threshold=0.4, showglyph=FALSE, bview="coronal",
savedir=tempdir())TRUE).rg=NULL processes all slices.FALSE).btoption=1), and the 3D-DSI grid b-table extracted from the diffusion data set (axial, coronal, sagittal} (default: "coronal").FALSE).tempdir().gqi.odfvmf outputs three data files in NIfTI format named
gqi.odfvmf uses a mixture of 2 and 4 von Mises-Fisher (vMF) distributions that serves as a model for directional ODF profile data, corresponding to multiple fibre orientations.
Statistical orientation estimation in gqi.odfvmf is based on von Mises clustering procedures provided by the R-package Starting with the raw diffusion signal acquired on a grid of q-space, the ODF profile is estimated at each voxel, considering a sampling density of unit vectors on a unit S2 grid. When a threshold is applied to the estimated ODF at each voxel, the non-thresholded unit vectors provide directional statistics information about the estimated ODF profile. The main ODF orientations at each voxel relevant for fibre tracking may be estimated by clustering the non-thresholded unit vectors.
The main diffusion data set used in the examples is a DICOM data set provided by the "Advanced Biomedical MRI Lab, National Taiwan University Hospital", which is included in the "DSI Studio" package, publicly available from the NITRC repository (
The output files rgbvolmap() or via the "FSL/fslview" tool.
These files may be used to perform white matter fibre tractography.
Hornik, K., and Gruen, B.
Yeh, F.-C., Wedeen, V. J., and Tseng, W.-Y. I. Generalized q-Sampling Imaging. IEEE Transactions on Medical Imaging 29, 9 (2010), 1626-1635.
Hankin, R. K. S. Special functions in R: introducing the
Adler, D., and Murdoch, D.
Auguie, B.
Barber, C. B., Habel, K., Grasman, R., Gramacy, R. B., Stahel, A., and Sterratt, D. C.
R Core Team.
Whitcher, B., Schmid, V. J., and Thornton, A. Working with the DICOM and NIfTI data standards in R. Journal of Statistical Software 44, 6 (2011), 1-28.
Jenkinson, M., Beckmann, C. F., Behrens, T. E., Woolrich, M. W., and Smith, S. M. FSL. NeuroImage 62, 2 (2012), 782-790.
gqi.odfvmflines,
gqi.odfpeaklines,
gqi.odfvxgrid,
rgbvolmap,
gqi.odfpeaks,
s2tessel.zorder,
plotglyph,
simulglyph.vmf,
simul.fandtasia,
simul.simplefield,
data,
data_brain,
data.bval,
data.bvec,
dsi203_bmax4000## Generate ODF volumes (GQI volume processing)
## for a range of slices using von Mises-Fisher clustering
gqi.odfvmf(depth=2, showglyph=FALSE, threshold=0.5, savedir=tempdir())
## RGB maps for range of slices processed by gqi.odfvmf()
rgbvolmap(fbase=tempdir(), rg=c(1,4), bview="coronal")
##-------------
## Show reconstructed glyphs in ODF processing
## for first and second main fibre direction determination
gqi.odfvmf(rg=c(1,1), bview="coronal", depth=3, showglyph=TRUE,
threshold=0.5)Run the code above in your browser using DataLab