gqi.odfvmflines implements a new methodology based on directional statistics to estimate fibre profiles from high angular resolution diffusion imaging data.
Statistical orientation estimation in gqi.odfvmf is based on von Mises-Fisher clustering procedures provided by the R-package gqi.odfvmflines(run=TRUE, fbase=NULL, roi=NULL, rg=c(1,1), swap=FALSE,
mddratio=1.24, depth=3, btoption=2, threshold=0.4, kdir=4, zfactor=5,
showglyph=FALSE, snapshot=FALSE, showimage="linesgfa", bview="coronal",
savedir=tempdir(), pngfig="odfvmf", bg="white", texturefile=NA)TRUE).roi=NULL) uses an all brain mask for the supplied data set.rg=c(1,1)); rg=NULL processes all slices.FALSE).btoption=1), and the 3D-DSI grid b-table extracted from the diffusion data set (FALSE).FALSE)."linesgfa").
Alternative options are:
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata")
(see Details).axial, coronal, sagittal} (default: "coronal").tempdir().snapshot is TRUE (default "odfvmf")."white")NA - no texture).gqi.odfvmflines produces line-maps of ODF profiles for diffusion data slices.
The line-maps may be overlayed with generalized fractional anisotropy (GFA) relief maps, diffusion data maps or ROI maps.
The file gqi.odfvmflines implements a mixture-model approach to clustering orientation distribution functions (ODFs) based on the von Mises-Fisher distributions.
The method focus on clustering data on the unit sphere, where complexity arises from representing ODF profiles as directional data.Starting with the raw diffusion signal acquired on a grid of q-space, the ODF profile is estimated at each voxel, considering a sampling density of unit vectors on a unit S2 grid. When a threshold is applied to the estimated ODF at each voxel, the non-thresholded unit vectors provide directional statistics information about the estimated ODF profile. The main ODF orientations at each voxel relevant for fibre tracking may be estimated by clustering the non-thresholded unit vectors.
The main diffusion data set used in the examples is a DICOM data set provided by the "Advanced Biomedical MRI Lab, National Taiwan University Hospital", which is included in the "DSI Studio" package, publicly available from the NITRC repository (
Slice map display and overlay selection is controlled by specifying one the arguments
c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata")
for showimages.
Meanings are as follows: "none" - no visualization; "gfa" - GFA map only; "lines" - line map only; "linesgfa" - GFA overlayed on line map; "linesrgbmap" - lines overlayed on RGB map (if available); "linesdata" -
Hornik, K., and Gruen, B.
Yeh, F.-C., Wedeen, V. J., and Tseng, W.-Y. I. Generalized q-Sampling Imaging. IEEE Transactions on Medical Imaging 29, 9 (2010), 1626-1635.
Hankin, R. K. S. Special functions in R: introducing the
Adler, D., and Murdoch, D.
Auguie, B.
Barber, C. B., Habel, K., Grasman, R., Gramacy, R. B., Stahel, A., and Sterratt, D. C.
R Core Team.
Whitcher, B., Schmid, V. J., and Thornton, A. Working with the DICOM and NIfTI data standards in R. Journal of Statistical Software 44, 6 (2011), 1-28.
Jenkinson, M., Beckmann, C. F., Behrens, T. E., Woolrich, M. W., and Smith, S. M. FSL. NeuroImage 62, 2 (2012), 782-790.
Zeileis, A., Hornik, K., and Murrell, P. Escaping RGBland: Selecting colors for statistical graphics. Computational Statistics & Data Analysis 53 (2009), 3259-3270.
gqi.odfvmf,
gqi.odfpeaks,
gqi.odfvmflines,
gqi.odfvxgrid,
plotglyph,
rgbvolmap,
s2tessel.zorder,
simulglyph.vmf,
simul.fandtasia,
simul.simplefield,
data,
data_brain,
data.bval,
data.bvec,
dsi203_bmax4000##-------------
## von Mises-Fisher fibre orientation mapping
## for a range of slices
gqi.odfvmflines(run=TRUE, rg=c(1,1), depth=2,
showimage="linesdata", threshold=0.5)
## display line-maps only
gqi.odfvmflines(run=FALSE, depth=2, showimage="lines")
## using GFA overlay
gqi.odfvmflines(run=FALSE, depth=2, showimage="linesgfa")
##-------------
## Show reconstructed glyphs in ODF processing
## for principal direction determination
gqi.odfvmflines(run=TRUE, depth=3,
showimage="linesdata", showglyph=TRUE, threshold=0.5)
##-------------
## using a ROI overlay
gqi.odfvmflines(run=TRUE, depth=3, roi="slfcst")
##-------------
## coronal view with texture for a single slice
rgbvolmap(texture=TRUE, transparent=TRUE)
gqi.odfvmflines(threshold=0.5, showimage="linesrgbmap",
texturefile=paste(tempdir(),"/rgbmap.png", sep=""))Run the code above in your browser using DataLab