Usage
gqi.odfvxgrid(gdi="gqi", fbase=NULL, rg=c(1,1), swap=FALSE, lambda=NULL,
depth=3, btoption=2, threshold=0.4, kdir=4, zfactor=5,
snapshot=FALSE, showimage="glyphgfa", bview="coronal",
savedir=tempdir(), pngfig="odfglyphs", bg="white", texture=NULL, ...)
Arguments
gdi
method of ODF reconstruction to use c("gqi", "gqi2") (default: "gqi").
fbase
Directory where the required input data files are located.
rg
range of slices to process (default option rg=c(1,1)); rg=NULL processes all slices.
swap
toggle radiological/neurological orientation (default: FALSE).
lambda
diffusion sampling length in gdi="gqi" and gdi="gqi2".
By default the following default values are used when lambda=NULL is specified: 1.24 in "gqi", 3 in "gqi2".
depth
sampling density on the hemisphere used in simulation (default N=321; depth=3).
btoption
b-table selection between btable.txt (btoption=1), and the 3D-DSI grid b-table extracted from the diffusion data set (data.bvec and data.bval). By default, the 3D-DSI grid b-table is used (btoption
threshold
thresholding generalized fractional anisotropy (GFA) value at each voxel (default: 0.4).
kdir
maximum number of fibre directions to map (default: 4).
zfactor
parameter controlling z-value in relief overlay maps (default: 5).
snapshot
logical variable controlling line-maps snapshots (default: FALSE).
showimage
object controlling visualization of line-maps (default: "glyphgfa").
Alternative options are:
c("none", "gfa", "glyph", "glyphgfa", "glyphrgbmap", "glyphdata")
(see Details).
bview
MRI slice view selection in {axial, coronal, sagittal} (default: "coronal").
savedir
directory for saving/loading processed results (default: tempdir().
pngfig
base-name of the PNG file when snapshot is TRUE (default "odfglyphs").
bg
map background colour (default "white")
texture
name of the PNG file to be used as RGB map overlay in some 'showimage' options (default NULL - no texture).
...
additional material properties for geometry appearance as specified in rgl.material.