Learn R Programming

gdimap (version 0.0-3)

gqi.odfvxgrid: Glyph Maps

Description

gqi.odfvxgrid produces glyph-map fields of reconstructed ODF profiles for voxels in slices.

Usage

gqi.odfvxgrid(fbase=NULL, rg=c(1,1), swap=FALSE, mddratio=1.24,
 depth=3, btoption=2, threshold=0.4, kdir=4, zfactor=5,
 snapshot=FALSE, showimage="glyphgfa", bview="coronal",
 savedir=tempdir(), pngfig="odfglyphs", bg="white", texturefile=NA)

Arguments

fbase
Directory where the required input data files are located.
rg
range of slices to process (default option rg=c(1,1)); rg=NULL processes all slices.
swap
toggle radiological/neurological orientation (default: FALSE).
mddratio
GQI parameter (default: 1.24).
depth
sampling density on the hemisphere used in simulation (default N=321; depth=3).
btoption
b-table selection between dsi203_bmax4000.txt (btoption=1), and the 3D-DSI grid b-table extracted from the diffusion data set (data.bvec and data.bval). By default, the 3D-DSI grid b-table is used (
threshold
thresholding generalized fractional anisotropy (GFA) value at each voxel (default: 0.4).
kdir
maximum number of fibre directions to map (default: 4).
zfactor
parameter controlling z-value in relief overlay maps (default: 5).
snapshot
logical variable controlling line-maps snapshots (default: FALSE).
showimage
object controlling visualization of line-maps (default: "glyphgfa"). Alternative options are: c("none", "gfa", "glyph", "glyphgfa", "glyphrgbmap", "glyphdata") (see Details).
bview
MRI slice view selection in {axial, coronal, sagittal} (default: "coronal").
savedir
directory for saving/loading processed results (default: tempdir().
pngfig
base-name of the PNG file when snapshot is TRUE (default "odfglyphs").
bg
map background colour (default "white")
texturefile
name of the PNG file to be used as RGB map overlay in some 'showimage' options (default NA - no texture).

concept

  • GQI Volume Processing
  • Glyph maps

Details

Generalized q-Sampling Imaging (GQI) is used for orientation distribution function (ODF) reconstruction. Slice glyph map display and overlay selection is controlled by specifying one the arguments c("none", "gfa", "glyph", "glyphgfa", "glyphrgbmap", "glyphdata") for showimages. Meanings are as follows: "none" - no overlay; "gfa" - GFA map only; "glyph" - glyph map only; "glyphgfa" - GFA overlayed on glyph map; "glyphrgbmap" - glyphs overlayed on RGB map (if available); "glyphdata" - data_brain.nii.gz is overlayed on line map.

References

Adler, D., and Murdoch, D. rgl: 3D visualization device system (OpenGL), 2012. R package version 0.92.880.

Auguie, B. gridExtra: functions in Grid graphics, 2012. R package version 0.9.1.

Barber, C. B., Habel, K., Grasman, R., Gramacy, R. B., Stahel, A., and Sterratt, D. C. geometry: Mesh generation and surface tesselation, 2012. R package version 0.3-2.

Zeileis, A., Hornik, K., and Murrell, P. Escaping RGBland: Selecting colors for statistical graphics. Computational Statistics & Data Analysis 53 (2009), 3259-3270.

See Also

gqi.odfpeaks, gqi.odfvmf, gqi.odfvmflines, s2tessel.zorder, plotglyph, rgbvolmap, simulglyph.vmf, simul.fandtasia, simul.simplefield

Examples

Run this code
## show glyph-map for selected slice
  gqi.odfvxgrid(threshold=0.5, depth=2, showimage="glyphgfa")
  ##----
  ## generate slice RGB map as texture
  rgbvolmap(texture=TRUE, transp=TRUE)
  ## coronal glyphs + RGBmap
  gqi.odfvxgrid(threshold=0.5, depth=2, showimage="glyphrgbmap",
    texturefile=paste(tempdir(),"/rgbmap.png", sep=""))

Run the code above in your browser using DataLab