Learn R Programming

gdimap (version 0.0-3)

simulglyph.vmf: Voxel Diffusion Profile Simulation and von Mises-Fisher Fibre Mapping

Description

The synthesized diffusion voxel profiles generated by synthfiberss2z are used to reconstruct ODF profiles using the GQI method for reconstruction. ODF profiles and fibre directions are estimated by relying on von Mises-Fisher (vMF) distributions for directional mapping.

Usage

simulglyph.vmf(s2grid=NULL, angles=c(20,100), depth=3, b=3000,
 mddratio=1.24, sigma=NULL, threshold=0.4, snapshot=FALSE,
 savedir=tempdir(), pngfig="glyph1", showglyph=TRUE)

Arguments

s2grid
S2 shell grid, or other equivalent user specified grid. By default s2grid=NULL means that the grid is generated by s2tessel.zorder.
angles
angles in degrees of fibres to be used in simulation (default: two fibres with angles c(20,100)).
depth
sampling densities on the hemisphere used in simulation (default N=321; depth=3).
b
strength of the magnetic diffusion gradient (default b-value=3000).
mddratio
GQI parameter (default: 1.24).
sigma
Rician noise level used in simulation; (default NULL).
threshold
thresholding generalized fractional anisotropy (GFA) value at each voxel (default: 0.4).
snapshot
logical variable controlling line-map snapshots (default: FALSE).
savedir
directory for saving/loading processed results (default: tempdir()).
pngfig
base-name of the PNG files when snapshot is TRUE (default "glyph1").
showglyph
logical variable controlling visualization of voxel glyphs (default: TRUE).

Value

  • simulglyph.vmf plots the reconstructed ODF profile together with the vMF-estimated fiber directions.

concept

  • Simulation
  • ODF visualization
  • Glyph mapping

Details

The number of fibres is automatically estimated from the diffusion profile. To decide on the number of components to select the Bayesian information criterion (BIC) is applied.

References

Ferreira da Silva, A. R. Facing the Challenge of Estimating Human Brain White Matter Pathways. In Proc. of the 4th International Joint Conference on Computational Intelligence (Oct. 2012), K. Madani, J. Kacprzyk, and J. Filipe, Eds., SciTePress, pp. 709-714.

Hornik, K., and Gruen, B. movMF: Mixtures of von Mises-Fisher Distributions, 2012. R package version 0.0-2.

Adler, D., and Murdoch, D. rgl: 3D visualization device system (OpenGL), 2012. R package version 0.92.880.

Barber, C. B., Habel, K., Grasman, R., Gramacy, R. B., Stahel, A., and Sterratt, D. C. geometry: Mesh generation and surface tessellation, 2012. R package version 0.3-2.

See Also

synthfiberss2z, plotglyph, gqi.odfvmflines, rgbvolmap, gqi.odfpeaks, gqi.odfpeaklines, gqi.odfvxgrid, simul.fandtasia, simul.simplefield

Examples

Run this code
## Examples of synthetized voxel diffusion glyphs, ODF glyphs,
    ## and vMF fiber orientation mapping 
    ##
    ## noise-free simulations and vMF estimation (2 directions)
    angles <- c(20,110); b <- 1500
    simulglyph.vmf(angles=angles,b=b)
    ## 2 direction, lower crossing-angles, higher b
    angles <- c(20,80); b <- 3000
    simulglyph.vmf(angles=angles,b=b)
    ## 2 direction, low croosing angle
    angles <- c(20,65); b <- 3000
    simulglyph.vmf(angles=angles,b=b)
    ## 3 directions
    angles <- c(20,80,140); b <- 3000
    simulglyph.vmf(angles=angles,b=b)
    # 3 directions
    angles <- c(0,60,120); b <- 3000
    simulglyph.vmf(angles=angles,b=b)
    ##------------------
    ## noisy simulations and vMF estimation
    angles <- c(20,110); b <- 1500; sigma <- 0.033
    simulglyph.vmf(angles=angles,b=b, sigma=sigma)
    # 2 direction, lower crossing-angles, higher b
    angles <- c(20,80); b <- 3000; sigma <- 0.033
    simulglyph.vmf(angles=angles,b=b, sigma=sigma)
    ## 2 direction, low croosing angle
    angles <- c(20,65); b <- 3000; sigma <- 0.033
    simulglyph.vmf(angles=angles,b=b, sigma=sigma)
    # 3 directions
    angles <- c(20,80,140); b <- 3000; sigma <- 0.033
    simulglyph.vmf(angles=angles,b=b, sigma=sigma)
    # 3 directions
    angles <- c(0,60,120); b <- 3000; sigma <- 0.033
    simulglyph.vmf(angles=angles,b=b, sigma=sigma)

Run the code above in your browser using DataLab